% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods-OnDiskMSnExp.R, R/methods-XCMSnExp.R
\docType{methods}
\name{extractMsData,OnDiskMSnExp-method}
\alias{extractMsData,OnDiskMSnExp-method}
\alias{extractMsData,XCMSnExp-method}
\alias{extractMsData}
\title{Extract a \code{data.frame} containing MS data}
\usage{
\S4method{extractMsData}{OnDiskMSnExp}(object, rt, mz, msLevel = 1L)

\S4method{extractMsData}{XCMSnExp}(object, rt, mz, msLevel = 1L,
  adjustedRtime = hasAdjustedRtime(object))
}
\arguments{
\item{object}{A \code{XCMSnExp} or \code{OnDiskMSnExp} object.}

\item{rt}{\code{numeric(2)} with the retention time range from which the
data should be extracted.}

\item{mz}{\code{numeric(2)} with the mz range.}

\item{msLevel}{\code{integer} defining the MS level(s) to which the data
should be sub-setted prior to extraction; defaults to
\code{msLevel = 1L}.}

\item{adjustedRtime}{(for \code{extractMsData,XCMSnExp}): \code{logical(1)}
specifying if adjusted or raw retention times should be reported.
Defaults to adjusted retention times, if these are present in
\code{object}.}
}
\value{
A \code{list} of length equal to the number of samples/files in
    \code{object}. Each element being a \code{data.frame} with columns
    \code{"rt"}, \code{"mz"} and \code{"i"} with the retention time, mz and
    intensity tuples of a file. If no data is available for the mz-rt range
    in a file a \code{data.frame} with 0 rows is returned for that file.
}
\description{
Extract a \code{data.frame} of retention time, mz and intensity
    values from each file/sample in the provided rt-mz range (or for the full
    data range if \code{rt} and \code{mz} are not defined).
}
\examples{
## Read some files from the test data package.
library(faahKO)
library(xcms)
fls <- dir(system.file("cdf/KO", package = "faahKO"), recursive = TRUE,
           full.names = TRUE)
raw_data <- readMSData(fls[1:2], mode = "onDisk")

## Read the full MS data for a defined mz-rt region.
res <- extractMsData(raw_data, mz = c(300, 320), rt = c(2700, 2900))

## We've got one data.frame per file
length(res)

## With number of rows:
nrow(res[[1]])

head(res[[1]])
}
\seealso{
\code{\link{XCMSnExp}} for the data object.
    \code{\link{plotMsData}} to plot the data for a single file.
}
\author{
Johannes Rainer
}
